Class: Google::Apis::WebsecurityscannerV1::ScanConfig
- Inherits:
-
Object
- Object
- Google::Apis::WebsecurityscannerV1::ScanConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/websecurityscanner_v1/classes.rb,
lib/google/apis/websecurityscanner_v1/representations.rb,
lib/google/apis/websecurityscanner_v1/representations.rb
Overview
A ScanConfig resource contains the configurations to launch a scan.
Instance Attribute Summary collapse
-
#authentication ⇒ Google::Apis::WebsecurityscannerV1::Authentication
Scan authentication configuration.
-
#blacklist_patterns ⇒ Array<String>
The excluded URL patterns as described in https://cloud.google.com/security- command-center/docs/how-to-use-web-security-scanner#excluding_urls Corresponds to the JSON property
blacklistPatterns. -
#display_name ⇒ String
Required.
-
#export_to_security_command_center ⇒ String
Controls export of scan configurations and results to Security Command Center.
-
#ignore_http_status_errors ⇒ Boolean
(also: #ignore_http_status_errors?)
Whether to keep scanning even if most requests return HTTP error codes.
-
#latest_run ⇒ Google::Apis::WebsecurityscannerV1::ScanRun
A ScanRun is a output-only resource representing an actual run of the scan.
-
#managed_scan ⇒ Boolean
(also: #managed_scan?)
Whether the scan config is managed by Web Security Scanner, output only.
-
#max_qps ⇒ Fixnum
The maximum QPS during scanning.
-
#name ⇒ String
Identifier.
-
#risk_level ⇒ String
The risk level selected for the scan Corresponds to the JSON property
riskLevel. -
#schedule ⇒ Google::Apis::WebsecurityscannerV1::Schedule
Scan schedule configuration.
-
#starting_urls ⇒ Array<String>
Required.
-
#static_ip_scan ⇒ Boolean
(also: #static_ip_scan?)
Whether the scan configuration has enabled static IP address scan feature.
-
#target_platforms ⇒ Array<String>
Set of Google Cloud platforms targeted by the scan.
-
#user_agent ⇒ String
The user agent used during scanning.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ScanConfig
constructor
A new instance of ScanConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ScanConfig
Returns a new instance of ScanConfig.
659 660 661 |
# File 'lib/google/apis/websecurityscanner_v1/classes.rb', line 659 def initialize(**args) update!(**args) end |
Instance Attribute Details
#authentication ⇒ Google::Apis::WebsecurityscannerV1::Authentication
Scan authentication configuration.
Corresponds to the JSON property authentication
575 576 577 |
# File 'lib/google/apis/websecurityscanner_v1/classes.rb', line 575 def authentication @authentication end |
#blacklist_patterns ⇒ Array<String>
The excluded URL patterns as described in https://cloud.google.com/security-
command-center/docs/how-to-use-web-security-scanner#excluding_urls
Corresponds to the JSON property blacklistPatterns
581 582 583 |
# File 'lib/google/apis/websecurityscanner_v1/classes.rb', line 581 def blacklist_patterns @blacklist_patterns end |
#display_name ⇒ String
Required. The user provided display name of the ScanConfig.
Corresponds to the JSON property displayName
586 587 588 |
# File 'lib/google/apis/websecurityscanner_v1/classes.rb', line 586 def display_name @display_name end |
#export_to_security_command_center ⇒ String
Controls export of scan configurations and results to Security Command Center.
Corresponds to the JSON property exportToSecurityCommandCenter
591 592 593 |
# File 'lib/google/apis/websecurityscanner_v1/classes.rb', line 591 def export_to_security_command_center @export_to_security_command_center end |
#ignore_http_status_errors ⇒ Boolean Also known as: ignore_http_status_errors?
Whether to keep scanning even if most requests return HTTP error codes.
Corresponds to the JSON property ignoreHttpStatusErrors
596 597 598 |
# File 'lib/google/apis/websecurityscanner_v1/classes.rb', line 596 def ignore_http_status_errors @ignore_http_status_errors end |
#latest_run ⇒ Google::Apis::WebsecurityscannerV1::ScanRun
A ScanRun is a output-only resource representing an actual run of the scan.
Next id: 12
Corresponds to the JSON property latestRun
603 604 605 |
# File 'lib/google/apis/websecurityscanner_v1/classes.rb', line 603 def latest_run @latest_run end |
#managed_scan ⇒ Boolean Also known as: managed_scan?
Whether the scan config is managed by Web Security Scanner, output only.
Corresponds to the JSON property managedScan
608 609 610 |
# File 'lib/google/apis/websecurityscanner_v1/classes.rb', line 608 def managed_scan @managed_scan end |
#max_qps ⇒ Fixnum
The maximum QPS during scanning. A valid value ranges from 5 to 20 inclusively.
If the field is unspecified or its value is set 0, server will default to 15.
Other values outside of [5, 20] range will be rejected with INVALID_ARGUMENT
error.
Corresponds to the JSON property maxQps
617 618 619 |
# File 'lib/google/apis/websecurityscanner_v1/classes.rb', line 617 def max_qps @max_qps end |
#name ⇒ String
Identifier. The resource name of the ScanConfig. The name follows the format
of 'projects/projectId/scanConfigs/scanConfigId'. The ScanConfig IDs are
generated by the system.
Corresponds to the JSON property name
624 625 626 |
# File 'lib/google/apis/websecurityscanner_v1/classes.rb', line 624 def name @name end |
#risk_level ⇒ String
The risk level selected for the scan
Corresponds to the JSON property riskLevel
629 630 631 |
# File 'lib/google/apis/websecurityscanner_v1/classes.rb', line 629 def risk_level @risk_level end |
#schedule ⇒ Google::Apis::WebsecurityscannerV1::Schedule
Scan schedule configuration.
Corresponds to the JSON property schedule
634 635 636 |
# File 'lib/google/apis/websecurityscanner_v1/classes.rb', line 634 def schedule @schedule end |
#starting_urls ⇒ Array<String>
Required. The starting URLs from which the scanner finds site pages.
Corresponds to the JSON property startingUrls
639 640 641 |
# File 'lib/google/apis/websecurityscanner_v1/classes.rb', line 639 def starting_urls @starting_urls end |
#static_ip_scan ⇒ Boolean Also known as: static_ip_scan?
Whether the scan configuration has enabled static IP address scan feature. If
enabled, the scanner will access applications from static IP addresses.
Corresponds to the JSON property staticIpScan
645 646 647 |
# File 'lib/google/apis/websecurityscanner_v1/classes.rb', line 645 def static_ip_scan @static_ip_scan end |
#target_platforms ⇒ Array<String>
Set of Google Cloud platforms targeted by the scan. If empty, APP_ENGINE will
be used as a default.
Corresponds to the JSON property targetPlatforms
652 653 654 |
# File 'lib/google/apis/websecurityscanner_v1/classes.rb', line 652 def target_platforms @target_platforms end |
#user_agent ⇒ String
The user agent used during scanning.
Corresponds to the JSON property userAgent
657 658 659 |
# File 'lib/google/apis/websecurityscanner_v1/classes.rb', line 657 def user_agent @user_agent end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 |
# File 'lib/google/apis/websecurityscanner_v1/classes.rb', line 664 def update!(**args) @authentication = args[:authentication] if args.key?(:authentication) @blacklist_patterns = args[:blacklist_patterns] if args.key?(:blacklist_patterns) @display_name = args[:display_name] if args.key?(:display_name) @export_to_security_command_center = args[:export_to_security_command_center] if args.key?(:export_to_security_command_center) @ignore_http_status_errors = args[:ignore_http_status_errors] if args.key?(:ignore_http_status_errors) @latest_run = args[:latest_run] if args.key?(:latest_run) @managed_scan = args[:managed_scan] if args.key?(:managed_scan) @max_qps = args[:max_qps] if args.key?(:max_qps) @name = args[:name] if args.key?(:name) @risk_level = args[:risk_level] if args.key?(:risk_level) @schedule = args[:schedule] if args.key?(:schedule) @starting_urls = args[:starting_urls] if args.key?(:starting_urls) @static_ip_scan = args[:static_ip_scan] if args.key?(:static_ip_scan) @target_platforms = args[:target_platforms] if args.key?(:target_platforms) @user_agent = args[:user_agent] if args.key?(:user_agent) end |