Class: Google::Apis::WebsecurityscannerV1::Schedule
- Inherits:
-
Object
- Object
- Google::Apis::WebsecurityscannerV1::Schedule
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/websecurityscanner_v1/classes.rb,
lib/google/apis/websecurityscanner_v1/representations.rb,
lib/google/apis/websecurityscanner_v1/representations.rb
Overview
Scan schedule configuration.
Instance Attribute Summary collapse
-
#interval_duration_days ⇒ Fixnum
Required.
-
#schedule_time ⇒ String
A timestamp indicates when the next run will be scheduled.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Schedule
constructor
A new instance of Schedule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Schedule
Returns a new instance of Schedule.
878 879 880 |
# File 'lib/google/apis/websecurityscanner_v1/classes.rb', line 878 def initialize(**args) update!(**args) end |
Instance Attribute Details
#interval_duration_days ⇒ Fixnum
Required. The duration of time between executions in days.
Corresponds to the JSON property intervalDurationDays
868 869 870 |
# File 'lib/google/apis/websecurityscanner_v1/classes.rb', line 868 def interval_duration_days @interval_duration_days end |
#schedule_time ⇒ String
A timestamp indicates when the next run will be scheduled. The value is
refreshed by the server after each run. If unspecified, it will default to
current server time, which means the scan will be scheduled to start
immediately.
Corresponds to the JSON property scheduleTime
876 877 878 |
# File 'lib/google/apis/websecurityscanner_v1/classes.rb', line 876 def schedule_time @schedule_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
883 884 885 886 |
# File 'lib/google/apis/websecurityscanner_v1/classes.rb', line 883 def update!(**args) @interval_duration_days = args[:interval_duration_days] if args.key?(:interval_duration_days) @schedule_time = args[:schedule_time] if args.key?(:schedule_time) end |